@@ -1102,7 +1102,7 @@ int  MainWindow::GetFolderSize (const QString &path )
   QDir dir ( path );
   QStringList::Iterator it;
   int size = 0;
-  QStringList files = dir.entryList ( QDir::AllEntries | QDir::NoDotAndDotDot );
+  QStringList files = dir.entryList ( QDir::AllEntries | QDir::Hidden | QDir::NoDotAndDotDot );
   it = files.begin();
   while ( it != files.end() ) {
     size += QFileInfo ( path, *it ).size();
