@@ -5,6 +5,7 @@
 #include <QMainWindow>
 #include <QModelIndex>
 #include <QListWidgetItem>
+#include <QProcess>
 //#include "loadimage.h"
 
 namespace Ui {
@@ -19,11 +20,16 @@ public:
     explicit MainWindow(QWidget *parent = 0, QString openfolder = "");
     ~MainWindow();
     Ui::MainWindow *ui;
+    QProcess *proc;
+    QStringList procesos;
 
     int GetFolderSize ( const QString &path );
     QString GetFileSize ( int size );
 
 public slots:
+    void checkDevice();
+    void execDevice();
+    void checkFinished(int);
     void CargarBrowser(QString directorio);
     void agregarArchivo(QString archivo);
     void dirChanged(const QString directorio);
@@ -46,6 +52,7 @@ private:
     //Thread *pepe;
 
 private slots:
+    void on_pushButton_customContextMenuRequested(QPoint pos);
     void on_h_full_clicked();
     void on_v_full_clicked();
     void on_search_textChanged(QString );
