@@ -102,7 +102,7 @@ QString Unzip::GetFileSize(int size)
 }
 
 
-void Unzip::pfinished(int code)
+void Unzip::pfinished(int)
 {
     QString line; int linea=0;
     QString texto2;
